Class: Moto::Test::Metadata
- Inherits:
-
Object
- Object
- Moto::Test::Metadata
- Defined in:
- lib/test/metadata.rb
Overview
Provides tools for accessing metadata embedded in test files
Instance Attribute Summary collapse
-
#test_path ⇒ Object
readonly
Absolute test path.
Instance Method Summary collapse
-
#description ⇒ Array
Of [String] which represent contents of #TICKET_URL.
-
#eql?(other) ⇒ Boolean
Overriden eql? so various comparisons, array substractions etc.
-
#initialize(test_path) ⇒ Metadata
constructor
A new instance of Metadata.
-
#tags ⇒ Array<String>
Which represent contents of #MOTO_TAGS.
-
#ticket_urls ⇒ Array
Of [String] which represent contents of #TICKET_URL.
Constructor Details
#initialize(test_path) ⇒ Metadata
Returns a new instance of Metadata.
10 11 12 |
# File 'lib/test/metadata.rb', line 10 def initialize(test_path) @test_path = test_path end |
Instance Attribute Details
#test_path ⇒ Object (readonly)
Absolute test path
7 8 9 |
# File 'lib/test/metadata.rb', line 7 def test_path @test_path end |
Instance Method Details
#description ⇒ Array
Returns of [String] which represent contents of #TICKET_URL.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/test/metadata.rb', line 66 def description if @description.nil? matches = text.scan(/^#(\s*)DESC:(.*?)$/) @description = '' if !matches.empty? matches.each do |match| @description += match[1] + "\n" end end end @description end |
#eql?(other) ⇒ Boolean
Overriden eql? so various comparisons, array substractions etc. can be perfromed on Metadata objects with them being represented by test’s location
85 86 87 88 89 90 91 |
# File 'lib/test/metadata.rb', line 85 def eql?(other) if self.class == other.class return self.test_path == other.test_path end false end |
#tags ⇒ Array<String>
Returns which represent contents of #MOTO_TAGS.
36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/test/metadata.rb', line 36 def if .nil? matches = text.match(/^#(\s*)MOTO_TAGS:(.*?)$/) if matches = matches.to_a[2].gsub(/\s*/, '').split(',') else = [] end end end |
#ticket_urls ⇒ Array
Returns of [String] which represent contents of #TICKET_URL.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/test/metadata.rb', line 51 def ticket_urls if @ticket_urls.nil? matches = text.match(/^#(\s*)TICKET_URLS:(.*?)$/) if matches @ticket_urls = matches.to_a[2].gsub(/\s*/, '').split(',') else @ticket_urls = [] end end @ticket_urls end |