Class: Moto::Test::Metadata

Inherits:
Object
  • Object
show all
Defined in:
lib/test/metadata.rb

Overview

Provides tools for accessing metadata embedded in test files

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(test_path) ⇒ Metadata

Returns a new instance of Metadata.

Parameters:

  • Absolute path to file with test



10
11
12
# File 'lib/test/metadata.rb', line 10

def initialize(test_path)
  @test_path = test_path
end

Instance Attribute Details

#test_pathObject (readonly)

Absolute test path



7
8
9
# File 'lib/test/metadata.rb', line 7

def test_path
  @test_path
end

Instance Method Details

#eql?(other) ⇒ Boolean

Overriden eql? so various comparisons, array substractions etc. can be perfromed on Metadata objects with them being represented by test’s location

Returns:



67
68
69
70
71
72
73
# File 'lib/test/metadata.rb', line 67

def eql?(other)
  if self.class == other.class
    return self.test_path == other.test_path
  end

  false
end

#tagsArray

Returns of [String] which represent contents of #MOTO_TAGS.

Returns:

  • of [String] which represent contents of #MOTO_TAGS



36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/test/metadata.rb', line 36

def tags
  if @tags.nil?
    matches = text.match(/^#(\s*)MOTO_TAGS:(.*?)$/)

    if matches
      @tags = matches.to_a[2].gsub(/\s*/, '').split(',')
    else
      @tags = []
    end
  end

  @tags
end

#ticket_urlString

Returns which represents contents of #TICKET_URL.

Returns:

  • which represents contents of #TICKET_URL



51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/test/metadata.rb', line 51

def ticket_url
  if @ticket_url.nil?
    matches = text.match(/^#(\s*)TICKET_URL:(.*?)$/)

    if matches
      @ticket_url = matches.to_a[2].gsub(/\s*/, '')
    else
      @ticket_url = ''
    end
  end

  @ticket_url
end